//---------------------------------------------------------------------------
// TDcjRegistryDlg Component
// Copyright (c) 1998 Michael Trier.  All Rights Reserved.
// See source file for restrictions.
//---------------------------------------------------------------------------
#ifndef DcjRegDlgH
#define DcjRegDlgH
//---------------------------------------------------------------------------
#include "Dcjdef.h"
#include <SysUtils.hpp>
#include <Controls.hpp>
#include <Classes.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Registry.hpp>
#include <ComCtrls.hpp>
#include "DcjCustomDlg.h"
#include "DcjRootKey.h"
//---------------------------------------------------------------------------
// forward declarations
class PACKAGE TDcjRegistryDlg;
//---------------------------------------------------------------------------
// TDcjNodePath class
//---------------------------------------------------------------------------
class TDcjNodePath : public TObject
{
private:
  AnsiString FNodePath;
  TDcjRootKey FRootKey;

public:
  // constructor
  __fastcall TDcjNodePath(AnsiString sNodePath, TDcjRootKey aRootKey);

public:
  // property accessors
  __property AnsiString NodePath = {read=FNodePath, write=FNodePath};
  __property TDcjRootKey RootKey = {read=FRootKey, write=FRootKey};
};
//---------------------------------------------------------------------------
// TDcjRegistryForm class
//---------------------------------------------------------------------------
class TDcjRegistryForm : public TDcjDialogForm
{
__published:	// IDE-managed Components
  TTreeView *tvwRegistry;
  TLabel *lblText;
  TButton *cmdCancel;
  TButton *cmdOK;
  TButton *cmdHelp;
  void __fastcall cmdOKClick(TObject *Sender);
  void __fastcall cmdCancelClick(TObject *Sender);
  void __fastcall tvwRegistryExpanding(TObject *Sender, TTreeNode *Node,
          bool &AllowExpansion);
  void __fastcall tvwRegistryDeletion(TObject *Sender, TTreeNode *Node);
  void __fastcall tvwRegistryClick(TObject *Sender);
private:	// User declarations
  AnsiString FNodePath;
  TDcjRootKey FRootKey;
  int iNodeLevel;
  int iCurrentLevel;
  TTreeNode *pCurrentNode;
  bool FLoadOnDemand;
  bool FShowRoot;

protected:
  void __fastcall RecurseRegistry(TDcjRootKey aRootKey, AnsiString sCurrentPath);
  void __fastcall AddKeyToTree(TDcjRootKey aRootKey, AnsiString sNodePath,
      AnsiString sKey);
  void __fastcall LoadRegistryKey(TDcjRootKey aRootKey, AnsiString sCurrentPath);

public:		// User declarations
 	/* TForm.Create */ __fastcall virtual TDcjRegistryForm(
      Classes::TComponent* AOwner) : TDcjDialogForm(AOwner) { }
	/* TForm.CreateNew */ __fastcall TDcjRegistryForm(Classes::TComponent* AOwner,
      int Dummy);
	/* TForm.Destroy */ __fastcall virtual ~TDcjRegistryForm(void) { }

  /* TWinControl.CreateParented */ __fastcall TDcjRegistryForm(HWND ParentWindow)
      : TDcjDialogForm(ParentWindow) { }

  void __fastcall LoadRegistryInfo(TDcjRootKey aRootKey,
      AnsiString sCurrentPath);

  __property TDcjRootKey RootKey = {read=FRootKey, write=FRootKey};

__published:
  __property bool LoadOnDemand = {read=FLoadOnDemand, write=FLoadOnDemand,
      default=true};
  __property AnsiString NodePath = {read=FNodePath, write=FNodePath};
  __property bool ShowRoot = {read=FShowRoot, write=FShowRoot};

};
//---------------------------------------------------------------------------
// TDcjRegistryDlg Declaration
//---------------------------------------------------------------------------
class PACKAGE TDcjRegistryDlg : public TDcjCustomDlg
{
private:
  TDcjRootKey FRootKey;
  AnsiString FNodePath;
  TTreeView *FTreeView;
  bool FLoadOnDemand;
  bool FShowRoot;
  bool FSorted;

protected:
  // overriden protected functions
  virtual TDcjRegistryForm* __fastcall CreateDcjDialog(void);
  virtual void __fastcall CreateFormObjects(TDcjRegistryForm *RegForm);
  virtual AnsiString __fastcall GetVersion(void);
  virtual TDcjRootKeyEnum __fastcall GetRootKey(void);
  virtual void __fastcall SetRootKey(TDcjRootKeyEnum Value);

public:
  __fastcall TDcjRegistryDlg(TComponent* Owner);
  __fastcall ~TDcjRegistryDlg(void);

  // overriden public member functions
  virtual void __fastcall Assign(TPersistent *Source);
  bool __fastcall Execute(void);
  virtual AnsiString __fastcall PreviewResults(void);

  // inherited public properties
  __property ModalResult;

  // access to the full TDcjRootKey object
  __property TDcjRootKey RootKeyObject = {read=FRootKey, write=FRootKey};

__published:
  // inherited published properties
  __property Name;
  __property Tag;
  __property Caption;
  __property Font;
  __property Text;
  __property HelpContext;
  __property Version;
  // published properties
  __property TDcjRootKeyEnum RootKey = {read=GetRootKey, write=SetRootKey};
  __property AnsiString NodePath = {read=FNodePath, write=FNodePath};
  __property bool LoadOnDemand = {read=FLoadOnDemand, write=FLoadOnDemand,
      default=true};
  __property bool ShowRoot = {read=FShowRoot, write=FShowRoot, default=false};
  __property bool Sorted = {read=FSorted, write=FSorted, default=false};
};
//---------------------------------------------------------------------------
#endif
